"""
******************************************************************************
* @author  ARMCNC site:www.armcnc.net github:armcnc.github.io
******************************************************************************
"""

class Machine:

    def __init__(self, framework):
        self.framework = framework
        self.user = "armcnc"
        self.axis = []
        self.is_alive = False
        self.info = None
        self.axes_tmp = ""

    def get_num_axis(self, axis):
        self.axes_tmp = ''.join(self.axis)
        num = self.axes_tmp.find(axis.upper())
        return num

    def get_num(self, axis):
        self.axes_tmp = "XYZABCUVW"
        num = self.axes_tmp.find(axis.upper())
        return num



"""
******************************************************************************
* @author  ARMCNC site:www.armcnc.net github:armcnc.github.io
******************************************************************************
"""
import time
import json
from .service import Service
from .log import Log

class Utils:

    def __init__(self, framework):
        self.framework = framework
        self.service = Service(self)
        self.log = Log(self)
        self.time = time
        self.json = json

    def get_service_status(self):
        return self.service.status

    def set_sleep(self, seconds):
        self.time.sleep(seconds)
